@@ -40,7 +40,7 @@
 #' @return An 'hfr' regression object.
 #' @author Johann Pfitzinger
 #' @references
-#' Pfitzinger, Johann (2024). Cluster Regularization via a Hierarchical Feature Regression. _Journal of Econometrics and Statistics_ (in press). URL https://doi.org/10.1016/j.ecosta.2024.01.003.
+#' Pfitzinger, Johann (2024). Cluster Regularization via a Hierarchical Feature Regression. _Econometrics and Statistics_ (in press). URL https://doi.org/10.1016/j.ecosta.2024.01.003.
 #'
 #' @examples
 #' x = matrix(rnorm(100 * 20), 100, 20)
@@ -127,7 +127,7 @@ hfr <- function(
     residuals = resid,
     x = x,
     y = y,
-    df = round(as.numeric(crossprod(v$dof, opt_par)), 4) + intercept,
+    df = round(as.numeric(crossprod(v$dof, opt_par)), 4),
     hgraph = list(cluster_object = v$clust, shrinkage_vector = opt_par,
                   included_levels = v$included_levels,
                   explained_variance = explained_variance,
